/*
 * Sonar, open source software quality management tool.
 * Copyright (C) 2009 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.maven;

import org.sonar.commons.resources.Resource;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.configuration.CompositeConfiguration;
import org.sonar.commons.configuration.ResourceDatabaseConfiguration;
import org.sonar.commons.database.DatabaseSession;
import org.sonar.plugins.api.maven.model.MavenPom;

import java.util.List;

public class DatabaseConfigurationLoader {
  private CompositeConfiguration configuration;
  private MavenPom pom;
  private DatabaseSession session;

  public DatabaseConfigurationLoader(CompositeConfiguration configuration, MavenPom pom, DatabaseSession session) {
    this.configuration = configuration;
    this.pom = pom;
    this.session = session;
  }

  public void start() {
    ResourceDatabaseConfiguration databaseConfig = new ResourceDatabaseConfiguration(session, getResource());
    if (databaseConfig != null) {
      configuration.addConfiguration(databaseConfig);
    }
  }

  private Resource getResource() {
    String resourceKey = pom.getRootPom().getKey();
    List<Resource> resources = session.getResults(Resource.class, "key", resourceKey, "enabled", true);
    if (CollectionUtils.isNotEmpty(resources)) {
      return resources.get(0);
    }
    return null;
  }
}
